#
# spec file for package python-codecov
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-codecov
Version:        2.1.13
Release:        1.4
Summary:        Hosted coverage reports
License:        Apache-2.0
URL:            https://github.com/codecov/codecov-python
Source:         https://files.pythonhosted.org/packages/source/c/codecov/codecov-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module requests >= 2.7.9}
# /SECTION
Requires:       python-coverage
Requires:       python-requests >= 2.7.9
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun):update-alternatives

%python_subpackages

%description
Hosted coverage reports for Github, Bitbucket and Gitlab.

%prep
%setup -q -n codecov-%{version}
sed -i -e '/^#!\//, 1d' codecov/__init__.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/codecov

%post
%python_install_alternative codecov

%postun
%python_uninstall_alternative codecov

%files %{python_files}
%defattr(-,root,root,-)
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/codecov
%{python_sitelib}/*

%changelog
* Sun May  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.1.13:
  * Add deprecation notice
  * Add migration guide link
* Tue Aug 24 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.1.12
  - Add Cirrus CI
  - Bump coverage from 5.3 to 5.3.1
  - Bump coverage from 5.3.1 to 5.4
  - Bump coverage from 5.4 to 5.5
  - Upgrade to GitHub-native Dependabot
- from version 2.1.11
  - Added option to disable printing of gcov-out
  - Handle exceptions that don't have a returncode
  - Update to Python 3.9
- from version 2.1.10
  - Output elapsed time with S3 upload
  - Improve error reporting in the "try_run" function and correctly
    include original command output in the error message
  - Added sleep between upload retries.
  - Ignore emacs lisp files
  - Fix error try_to_run using | without shell=True (fix #284)
  - Bump coverage from 4.5.4 to 5.2.1
  - Update python versions
  - Add license scan report and status
  - Update README with accurate links
  - Bump coverage from 5.2.1 to 5.3
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.1.9:
  * Remove token restriction as it is changed server-side
  * support for CODECOV_FLAGS
  * ability to specify number of upload retries
* Thu Jul  9 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.1.7:
  * Fix pinned coverage version
  * Fix GitHub Actions implementation
  * Implement retries on Codecov API calls
  * Add GitHub Actions CI detection
  * Add CODECOV_NAME as default for name
  * Fix command line quoting on Windows
  * Fix GitLab CI project directory detection on Windows
  * Fix GitLab CI post version 9
  * Check text for NoneType on writes
  * Include the cacert in the PUT call when uploading to S3
  * Fixed gcov not being found in certain instances
  * Fix find command not working on Windows
  * Add support for gzipping reports
  * Dynamic syncing of version
  * Fix command when neither hg or git are not available
  * Remove x-amz-acl header
  * Cleaning TOC generation
  * fixed string issues
  * fixed broken subprocess handling
  * fixed reported command injection vulnerability.
- Drop LICENSE file, included directly in the tarball
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Aug 13 2018 mcepl@suse.com
- Remove dependency on unittest2
  (tests are not run at all, because they depend on network)
* Tue May 29 2018 toddrme2178@gmail.com
- Update to 2.0.15
  * add `-X s3` to disable direct to S3 uploading
- Update to 2.0.14
  * fixed coverage combine
- Update to 2.0.13
  * fix encoding issues
- Update to 2.0.12
  * revert merge commit fix, back to old way
- Update to 2.0.11
  * fix merge commit when it's a pull request
  * remove snapci, business closed
  * skip vendor directories for gcov parsing
  * run coverage combine not merge
  * fix report encoding
- Update to 2.0.10
  * fix uploading when reports contain characters outside of latin-1
  * remove reduced_redundancy header from
- Add license file
* Tue May 29 2018 toddrme2178@gmail.com
- Add license and doc files
- Use license tag
- Spec file cleanups
* Sat Mar  3 2018 arun@gmx.de
- specfile:
  * update copyright year
  * don't use python_module for Requires
* Thu Jul 13 2017 toddrme2178@gmail.com
- Initial version
